@@ -8,7 +8,7 @@ use Type::Tiny 1.000005 ();
 use Type::Registry ();
 use Type::Utils qw(class_type);
 
-use Function::Parameters 1.0703 ();
+use Function::Parameters 1.0703 qw(:lax);
 use Import::Into 1.002004 ();
 use Syntax::Feature::Try 1.003 ();
 use Data::OptList 0.109 ();
@@ -17,7 +17,7 @@ use Carp qw(croak confess);
 
 our @EXPORT;
 
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 my %OPTIONS;
 
@@ -97,6 +97,7 @@ sub import {
 sub _reify_type {
     my ($typedef, $package) = @_;
     my ($caller, $file, $line) = caller;
+    $package //= $caller;
     my $options = $OPTIONS{$package} || {};
     my $type;
     eval {
@@ -128,7 +129,7 @@ Moove - functions and methods with parameter lists and type constraints
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
